'/table_name', 'application.controllers.table_name.index.Index',
'/table_name/view/(.+)', 'application.controllers.table_name.view.View',
'/table_name/edit/(.+)', 'application.controllers.table_name.edit.Edit',
'/table_name/delete/(.+)', 'application.controllers.table_name.delete.Delete',
'/table_name/insert', 'application.controllers.table_name.insert.Insert',